@@ -20,4 +20,4 @@
 
 from .feature_elimination import ShapRFECV
 
-__all__ = ['ShapRFECV']
\ No newline at end of file
+__all__ = ["ShapRFECV"]
