@@ -22,4 +22,4 @@ from .inspector import InspectorShap
 from .shap_dependence import TreeDependencePlotter
 from .model_interpret import ShapModelInterpreter
 
-__all__ = ['InspectorShap', 'TreeDependencePlotter', 'ShapModelInterpreter']
\ No newline at end of file
+__all__ = ["InspectorShap", "TreeDependencePlotter", "ShapModelInterpreter"]
