@@ -24,8 +24,14 @@ import matplotlib.pyplot as plt
 from probatus.metric_volatility.metric import get_metric
 from joblib import Parallel, delayed
 from tqdm.auto import tqdm
-from probatus.utils import get_scorers, assure_list_of_strings,\
-    assure_list_values_allowed, BaseFitComputePlotClass, preprocess_data, preprocess_labels
+from probatus.utils import (
+    get_scorers,
+    assure_list_of_strings,
+    assure_list_values_allowed,
+    BaseFitComputePlotClass,
+    preprocess_data,
+    preprocess_labels,
+)
 from probatus.metric_volatility.utils import check_sampling_input
 from probatus.stat_tests import DistributionStatistics
 import warnings
@@ -37,9 +43,16 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
         own. Implements common API that can be used by all subclasses.
     """
 
-
-    def __init__(self, clf, scoring='roc_auc', test_prc=0.25, n_jobs=1, stats_tests_to_apply=None, verbose=0,
-                 random_state=None):
+    def __init__(
+        self,
+        clf,
+        scoring="roc_auc",
+        test_prc=0.25,
+        n_jobs=1,
+        stats_tests_to_apply=None,
+        verbose=0,
+        random_state=None,
+    ):
         """
         Initializes the class
 
@@ -87,25 +100,35 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
         self.iterations_results = None
         self.report = None
         self.verbose = verbose
-        self.allowed_stats_tests = list(DistributionStatistics.statistical_test_dict.keys())
+        self.allowed_stats_tests = list(
+            DistributionStatistics.statistical_test_dict.keys()
+        )
 
         # TODO set reasonable default value for the parameter, to choose the statistical test for the user for different
         #  ways to compute volatility
         if stats_tests_to_apply is not None:
-            self.stats_tests_to_apply = assure_list_of_strings(stats_tests_to_apply, 'stats_tests_to_apply')
-            assure_list_values_allowed(variable=self.stats_tests_to_apply,
-                                       variable_name='stats_tests_to_apply',
-                                       allowed_values=self.allowed_stats_tests)
+            self.stats_tests_to_apply = assure_list_of_strings(
+                stats_tests_to_apply, "stats_tests_to_apply"
+            )
+            assure_list_values_allowed(
+                variable=self.stats_tests_to_apply,
+                variable_name="stats_tests_to_apply",
+                allowed_values=self.allowed_stats_tests,
+            )
         else:
             self.stats_tests_to_apply = []
 
         self.stats_tests_objects = []
         if len(self.stats_tests_to_apply) > 0:
-            if self.verbose>0:
-                warnings.warn("Computing statistics for distributions is an experimental feature. While using it, keep "
-                              "in mind that the samples of metrics might be correlated.")
+            if self.verbose > 0:
+                warnings.warn(
+                    "Computing statistics for distributions is an experimental feature. While using it, keep "
+                    "in mind that the samples of metrics might be correlated."
+                )
             for test_name in self.stats_tests_to_apply:
-                self.stats_tests_objects.append(DistributionStatistics(statistical_test=test_name))
+                self.stats_tests_objects.append(
+                    DistributionStatistics(statistical_test=test_name)
+                )
 
         self.scorers = get_scorers(scoring)
 
@@ -143,8 +166,12 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
 
         self._check_if_fitted()
         if self.report is None:
-            raise(ValueError('Report is None, thus it has not been computed by fit method. Please extend the '
-                             'BaseVolatilityEstimator class, overwrite fit method, and within fit run compute_report()'))
+            raise (
+                ValueError(
+                    "Report is None, thus it has not been computed by fit method. Please extend the "
+                    "BaseVolatilityEstimator class, overwrite fit method, and within fit run compute_report()"
+                )
+            )
 
         if metrics is None:
             return self.report
@@ -153,7 +180,14 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
                 metrics = [metrics]
             return self.report.loc[metrics]
 
-    def plot(self, metrics=None, bins=10, show=True, height_per_subplot=5, width_per_subplot=5):
+    def plot(
+        self,
+        metrics=None,
+        bins=10,
+        show=True,
+        height_per_subplot=5,
+        width_per_subplot=5,
+    ):
         """
         Plots distribution of the metric
 
@@ -182,8 +216,14 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
         target_report = self.compute(metrics=metrics)
 
         if target_report.shape[0] >= 1:
-            fig, axs = plt.subplots(target_report.shape[0], 2, figsize=(width_per_subplot*2,
-                                                                        height_per_subplot*target_report.shape[0]))
+            fig, axs = plt.subplots(
+                target_report.shape[0],
+                2,
+                figsize=(
+                    width_per_subplot * 2,
+                    height_per_subplot * target_report.shape[0],
+                ),
+            )
 
             # Enable traversing the axs
             axs = axs.flatten()
@@ -192,19 +232,25 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
             for metric, row in target_report.iterrows():
                 train, test, delta = self._get_samples_to_plot(metric_name=metric)
 
-                axs[axis_index].hist(train, alpha=0.5, label='Train {}'.format(metric), bins=bins)
-                axs[axis_index].hist(test, alpha=0.5, label='Test {}'.format(metric), bins=bins)
-                axs[axis_index].set_title('Distributions {}'.format(metric))
-                axs[axis_index].legend(loc='upper right')
+                axs[axis_index].hist(
+                    train, alpha=0.5, label="Train {}".format(metric), bins=bins
+                )
+                axs[axis_index].hist(
+                    test, alpha=0.5, label="Test {}".format(metric), bins=bins
+                )
+                axs[axis_index].set_title("Distributions {}".format(metric))
+                axs[axis_index].legend(loc="upper right")
 
-                axs[axis_index+1].hist(delta, alpha=0.5, label='Delta {}'.format(metric), bins=bins)
-                axs[axis_index+1].set_title('Distributions delta {}'.format(metric))
-                axs[axis_index+1].legend(loc='upper right')
+                axs[axis_index + 1].hist(
+                    delta, alpha=0.5, label="Delta {}".format(metric), bins=bins
+                )
+                axs[axis_index + 1].set_title("Distributions delta {}".format(metric))
+                axs[axis_index + 1].legend(loc="upper right")
 
-                axis_index+=2
+                axis_index += 2
 
             for ax in axs.flat:
-                ax.set(xlabel='{} score'.format(metric), ylabel='Results count')
+                ax.set(xlabel="{} score".format(metric), ylabel="Results count")
 
             if show:
                 plt.show()
@@ -222,10 +268,12 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
                 Name of metric for which the data should be selected.
         """
 
-        current_metric_results = self.iterations_results[self.iterations_results['metric_name'] == metric_name]
-        train = current_metric_results['train_score']
-        test = current_metric_results['test_score']
-        delta = current_metric_results['delta_score']
+        current_metric_results = self.iterations_results[
+            self.iterations_results["metric_name"] == metric_name
+        ]
+        train = current_metric_results["train_score"]
+        test = current_metric_results["test_score"]
+        delta = current_metric_results["delta_score"]
 
         return train, test, delta
 
@@ -235,23 +283,40 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
         store them as report.
         """
 
-        unique_metrics = self.iterations_results['metric_name'].unique()
+        unique_metrics = self.iterations_results["metric_name"].unique()
 
         # Get columns which will be filled
         stats_tests_columns = []
         for stats_tests_object in self.stats_tests_objects:
-            stats_tests_columns.append('{} statistic'.format(stats_tests_object.statistical_test_name))
-            stats_tests_columns.append('{} p-value'.format(stats_tests_object.statistical_test_name))
-        stats_columns = ['train_mean', 'train_std', 'test_mean', 'test_std', 'delta_mean', 'delta_std']
+            stats_tests_columns.append(
+                "{} statistic".format(stats_tests_object.statistical_test_name)
+            )
+            stats_tests_columns.append(
+                "{} p-value".format(stats_tests_object.statistical_test_name)
+            )
+        stats_columns = [
+            "train_mean",
+            "train_std",
+            "test_mean",
+            "test_std",
+            "delta_mean",
+            "delta_std",
+        ]
         report_columns = stats_columns + stats_tests_columns
 
         self.report = pd.DataFrame([], columns=report_columns)
 
         for metric in unique_metrics:
-            metric_iterations_results = self.iterations_results[self.iterations_results['metric_name'] == metric]
+            metric_iterations_results = self.iterations_results[
+                self.iterations_results["metric_name"] == metric
+            ]
             metrics = self._compute_mean_std_from_runs(metric_iterations_results)
-            stats_tests_values = self._compute_stats_tests_values(metric_iterations_results)
-            metric_row = pd.DataFrame([metrics + stats_tests_values], columns=report_columns, index=[metric])
+            stats_tests_values = self._compute_stats_tests_values(
+                metric_iterations_results
+            )
+            metric_row = pd.DataFrame(
+                [metrics + stats_tests_values], columns=report_columns, index=[metric]
+            )
             self.report = self.report.append(metric_row)
 
     def _compute_mean_std_from_runs(self, metric_iterations_results):
@@ -266,13 +331,20 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
             (list):
                 List containing mean and std of train, test and deltas.
         """
-        train_mean_score = np.mean(metric_iterations_results['train_score'])
-        test_mean_score = np.mean(metric_iterations_results['test_score'])
-        delta_mean_score = np.mean(metric_iterations_results['delta_score'])
-        train_std_score = np.std(metric_iterations_results['train_score'])
-        test_std_score = np.std(metric_iterations_results['test_score'])
-        delta_std_score = np.std(metric_iterations_results['delta_score'])
-        return [train_mean_score, train_std_score, test_mean_score, test_std_score, delta_mean_score, delta_std_score]
+        train_mean_score = np.mean(metric_iterations_results["train_score"])
+        test_mean_score = np.mean(metric_iterations_results["test_score"])
+        delta_mean_score = np.mean(metric_iterations_results["delta_score"])
+        train_std_score = np.std(metric_iterations_results["train_score"])
+        test_std_score = np.std(metric_iterations_results["test_score"])
+        delta_std_score = np.std(metric_iterations_results["delta_score"])
+        return [
+            train_mean_score,
+            train_std_score,
+            test_mean_score,
+            test_std_score,
+            delta_mean_score,
+            delta_std_score,
+        ]
 
     def _compute_stats_tests_values(self, metric_iterations_results):
         """
@@ -288,12 +360,14 @@ class BaseVolatilityEstimator(BaseFitComputePlotClass):
         """
         statistics = []
         for stats_test in self.stats_tests_objects:
-            stats, p_value = \
-                stats_test.compute(metric_iterations_results['test_score'], metric_iterations_results['train_score'])
+            stats, p_value = stats_test.compute(
+                metric_iterations_results["test_score"],
+                metric_iterations_results["train_score"],
+            )
             statistics += [stats, p_value]
         return statistics
 
-    def fit_compute(self,  *args, **kwargs):
+    def fit_compute(self, *args, **kwargs):
         """
         Runs trains and evaluates a number of models on train and test sets extracted using different random seeds.
             Reports the statistics of the selected metric.
@@ -330,10 +404,22 @@ class TrainTestVolatility(BaseVolatilityEstimator):
     <img src="../img/metric_volatility_train_test.png" width="500" />
     """
 
-
-    def __init__(self, clf, iterations=1000, scoring='roc_auc', sample_train_test_split_seed=True,
-                 train_sampling_type=None, test_sampling_type=None, train_sampling_fraction=1, test_sampling_fraction=1,
-                 test_prc=0.25, n_jobs=1, stats_tests_to_apply=None, verbose=0, random_state=None):
+    def __init__(
+        self,
+        clf,
+        iterations=1000,
+        scoring="roc_auc",
+        sample_train_test_split_seed=True,
+        train_sampling_type=None,
+        test_sampling_type=None,
+        train_sampling_fraction=1,
+        test_sampling_fraction=1,
+        test_prc=0.25,
+        n_jobs=1,
+        stats_tests_to_apply=None,
+        verbose=0,
+        random_state=None,
+    ):
 
         """
         Initializes the class.
@@ -405,17 +491,24 @@ class TrainTestVolatility(BaseVolatilityEstimator):
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
         """
-        super().__init__(clf=clf, scoring=scoring, test_prc=test_prc, n_jobs=n_jobs,
-                         stats_tests_to_apply=stats_tests_to_apply, verbose=verbose, random_state=random_state)
+        super().__init__(
+            clf=clf,
+            scoring=scoring,
+            test_prc=test_prc,
+            n_jobs=n_jobs,
+            stats_tests_to_apply=stats_tests_to_apply,
+            verbose=verbose,
+            random_state=random_state,
+        )
         self.iterations = iterations
         self.train_sampling_type = train_sampling_type
         self.test_sampling_type = test_sampling_type
-        self.sample_train_test_split_seed=sample_train_test_split_seed
+        self.sample_train_test_split_seed = sample_train_test_split_seed
         self.train_sampling_fraction = train_sampling_fraction
         self.test_sampling_fraction = test_sampling_fraction
 
-        check_sampling_input(train_sampling_type, train_sampling_fraction, 'train')
-        check_sampling_input(test_sampling_type, test_sampling_fraction, 'test')
+        check_sampling_input(train_sampling_type, train_sampling_fraction, "train")
+        check_sampling_input(test_sampling_type, test_sampling_fraction, "test")
 
     def fit(self, X, y, column_names=None):
         """
@@ -439,8 +532,12 @@ class TrainTestVolatility(BaseVolatilityEstimator):
         """
         super().fit()
 
-        self.X, self.column_names = preprocess_data(X, X_name='X', column_names=column_names, verbose=self.verbose)
-        self.y = preprocess_labels(y, y_name='y', index=self.X.index, verbose=self.verbose)
+        self.X, self.column_names = preprocess_data(
+            X, X_name="X", column_names=column_names, verbose=self.verbose
+        )
+        self.y = preprocess_labels(
+            y, y_name="y", index=self.X.index, verbose=self.verbose
+        )
 
         if self.sample_train_test_split_seed:
             random_seeds = np.random.random_integers(0, 999999, self.iterations)
@@ -452,12 +549,21 @@ class TrainTestVolatility(BaseVolatilityEstimator):
         if self.verbose > 0:
             random_seeds = tqdm(random_seeds)
 
-        results_per_iteration = Parallel(n_jobs=self.n_jobs)(delayed(get_metric)(
-            X=self.X, y=self.y, clf=self.clf, test_size=self.test_prc, split_seed=split_seed,
-            scorers=self.scorers, train_sampling_type=self.train_sampling_type,
-            test_sampling_type=self.test_sampling_type, train_sampling_fraction=self.train_sampling_fraction,
-            test_sampling_fraction=self.test_sampling_fraction
-        ) for split_seed in random_seeds)
+        results_per_iteration = Parallel(n_jobs=self.n_jobs)(
+            delayed(get_metric)(
+                X=self.X,
+                y=self.y,
+                clf=self.clf,
+                test_size=self.test_prc,
+                split_seed=split_seed,
+                scorers=self.scorers,
+                train_sampling_type=self.train_sampling_type,
+                test_sampling_type=self.test_sampling_type,
+                train_sampling_fraction=self.train_sampling_fraction,
+                test_sampling_fraction=self.test_sampling_fraction,
+            )
+            for split_seed in random_seeds
+        )
 
         self.iterations_results = pd.concat(results_per_iteration, ignore_index=True)
 
@@ -485,8 +591,17 @@ class SplitSeedVolatility(TrainTestVolatility):
 
     """
 
-    def __init__(self, clf, iterations=1000, scoring='roc_auc', test_prc=0.25, n_jobs=1, stats_tests_to_apply=None,
-                 verbose=0, random_state=None):
+    def __init__(
+        self,
+        clf,
+        iterations=1000,
+        scoring="roc_auc",
+        test_prc=0.25,
+        n_jobs=1,
+        stats_tests_to_apply=None,
+        verbose=0,
+        random_state=None,
+    ):
         """
         Initializes the class
 
@@ -530,10 +645,21 @@ class SplitSeedVolatility(TrainTestVolatility):
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
         """
-        super().__init__(clf=clf, sample_train_test_split_seed=True, train_sampling_type=None,
-                         test_sampling_type=None, train_sampling_fraction=1,  test_sampling_fraction=1,
-                         iterations=iterations, scoring=scoring, test_prc=test_prc, n_jobs=n_jobs,
-                         stats_tests_to_apply=stats_tests_to_apply, verbose=verbose, random_state=random_state)
+        super().__init__(
+            clf=clf,
+            sample_train_test_split_seed=True,
+            train_sampling_type=None,
+            test_sampling_type=None,
+            train_sampling_fraction=1,
+            test_sampling_fraction=1,
+            iterations=iterations,
+            scoring=scoring,
+            test_prc=test_prc,
+            n_jobs=n_jobs,
+            stats_tests_to_apply=stats_tests_to_apply,
+            verbose=verbose,
+            random_state=random_state,
+        )
 
 
 class BootstrappedVolatility(TrainTestVolatility):
@@ -556,8 +682,19 @@ class BootstrappedVolatility(TrainTestVolatility):
     <img src="../img/metric_volatility_bootstrapped.png" width="500" />
     """
 
-    def __init__(self, clf, iterations=1000, scoring='roc_auc', train_sampling_fraction=1, test_sampling_fraction=1,
-                 test_prc=0.25, n_jobs=1, stats_tests_to_apply=None, verbose=0, random_state=None):
+    def __init__(
+        self,
+        clf,
+        iterations=1000,
+        scoring="roc_auc",
+        train_sampling_fraction=1,
+        test_sampling_fraction=1,
+        test_prc=0.25,
+        n_jobs=1,
+        stats_tests_to_apply=None,
+        verbose=0,
+        random_state=None,
+    ):
         """
         Initializes the class.
 
@@ -607,8 +744,18 @@ class BootstrappedVolatility(TrainTestVolatility):
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
         """
-        super().__init__(clf=clf, sample_train_test_split_seed=False, train_sampling_type='bootstrap',
-                         test_sampling_type='bootstrap', iterations=iterations, scoring=scoring,
-                         train_sampling_fraction=train_sampling_fraction, test_sampling_fraction=test_sampling_fraction,
-                         test_prc=test_prc, n_jobs=n_jobs, stats_tests_to_apply=stats_tests_to_apply, verbose=verbose,
-                         random_state=random_state)
+        super().__init__(
+            clf=clf,
+            sample_train_test_split_seed=False,
+            train_sampling_type="bootstrap",
+            test_sampling_type="bootstrap",
+            iterations=iterations,
+            scoring=scoring,
+            train_sampling_fraction=train_sampling_fraction,
+            test_sampling_fraction=test_sampling_fraction,
+            test_prc=test_prc,
+            n_jobs=n_jobs,
+            stats_tests_to_apply=stats_tests_to_apply,
+            verbose=verbose,
+            random_state=random_state,
+        )
